import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_ec2
import aws_cdk.aws_kms
import aws_cdk.cloud_assembly_schema
import aws_cdk.core
import aws_cdk.cx_api
import constructs

__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-efs", "1.33.0", __name__[0:-6], "aws-efs@1.33.0.jsii.tgz")

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
